=========================
 Date handling functions
=========================

.. _fluent-date:

Fluent.date
-----------

TODO!


.. _fluent-formatteddate:

Fluent.formattedDate
--------------------

TODO!

Example of how it works is in the tests:

* https://github.com/elm-fluent/elm-fluent/blob/641a3bd889a95f165ff70348a321698455ce907d/tests/test_project/Main.elm#L160
* https://github.com/elm-fluent/elm-fluent/blob/641a3bd889a95f165ff70348a321698455ce907d/tests/test_project/Main.elm#L103
